@@ -3,10 +3,10 @@ from typing import Union
 import matplotlib as mpl
 import matplotlib.pyplot as plt
 import numpy as np
-from scipy.integrate import cumulative_trapezoid, trapz
 from rich import print
 from rich.console import Console
 from rich.table import Column, Table
+from scipy.integrate import cumulative_trapezoid, trapz
 
 from ._const_duct_spec import const_duct_spec
 from ._elas_resp_spec import elas_resp_spec
@@ -37,7 +37,9 @@ class SeismoGM:
                  ) -> None:
         self.dt = dt
         self.acc = np.array(acc)
-        self.nacc = len(acc)
+        if np.abs(self.acc[0]) > 1e-5:
+            self.acc = np.insert(self.acc, 0, 0)
+        self.nacc = len(self.acc)
         self.time = np.arange(self.nacc) * dt
 
         # Arias IMs
@@ -541,7 +543,7 @@ class SeismoGM:
         y0 = self.get_pga() * 0.05
         acc = np.abs(self.acc)
         below = acc < y0
-        above = acc >= y0
+        above = acc > y0
         kth1 = below[0:-1] & above[1:]
         kth2 = above[0:-1] & below[1:]
         kp1 = np.array([*kth1, False])
